==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-volume/translations/volume_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="63"/>
        <source>Increase sound volume</source>
        <translation>הגברת עצמת השמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="69"/>
        <source>Decrease sound volume</source>
        <translation>הנמכת עצמת השמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="75"/>
        <source>Mute/unmute sound volume</source>
        <translation>השתקה/השמעה של צלילים</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="136"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>בקרת עצמת שמע: אין אפשרות לרשום את קיצורי הדרך הבאים: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="286"/>
        <source>Volume: %1%%2</source>
        <translation>עצמת שמע: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="286"/>
        <source>(muted)</source>
        <translation>(מושתק)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>הגדרות בקרת עצמת שמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>התקן לבקרה</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>התנהגות</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>השתקה בכפתור אמצעי</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>הצגה בלחיצה עם העכבר</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>לאפשר עצמת שמע מעל 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>תמיד להודיע על שינויים בעצמת השמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>צעדי התאמת עצמת שמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>מערבל חיצוני</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>הפעלת מערבל</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>מ&amp;ערבל</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-volume/translations/volume_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>הגברת עצמת השמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>הנמכת עצמת השמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>השתקה/השמעה של צלילים</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>בקרת עצמת שמע: אין אפשרות לרשום את קיצורי הדרך הבאים: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>Volume: %1%%2</source>
        <translation>עצמת שמע: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="291"/>
        <source>(muted)</source>
        <translation>(מושתק)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>הגדרות בקרת עצמת שמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>התקן לבקרה</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>התנהגות</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>השתקה בכפתור אמצעי</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Show on mouse click</source>
        <translation>הצגה בלחיצה עם העכבר</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>לאפשר עצמת שמע מעל 100% (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Always notify about volume changes</source>
        <translation>תמיד להודיע על שינויים בעצמת השמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="91"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>להודיע על שינויי עצמת שמע עם המקלדת</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="106"/>
        <source>Volume adjust step</source>
        <translation>צעדי התאמת עצמת שמע</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="125"/>
        <source>External Mixer</source>
        <translation>מערבל חיצוני</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="54"/>
        <source>Launch mixer</source>
        <translation>הפעלת מערבל</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="55"/>
        <source>Mi&amp;xer</source>
        <translation>מ&amp;ערבל</translation>
    </message>
</context>
</TS>
